"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.sourceNodes = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _camelcaseKeysRecursive = _interopRequireDefault(require("camelcase-keys-recursive"));

var _createClient = require("./create-client");

var _fetch = require("./fetch");

var _utils = require("./utils");

var _mock = require("./mock");

const sourceNodes = async ({
  actions: {
    createNode
  },
  createNodeId,
  createContentDigest
}, {
  shopName,
  shopifyAccessToken,
  yotpoAppKey,
  yotpoPerPage = 149,
  apiVersion = "2019-07",
  createDefaultObject = false
}) => {
  if (!shopName || !shopifyAccessToken || !yotpoAppKey) {
    console.log("\nMissing configurations - shopName, shopifyAccessToken and yotpoAppKey are required");
    process.exit(1);
  }

  const shopifyClient = await (0, _createClient.createShopifyClient)({
    shopName,
    shopifyAccessToken,
    apiVersion
  });

  if (createDefaultObject) {
    await (0, _utils.createNodeFactory)(createNode, createNodeId, createContentDigest, _mock.mockYotpoResponse);
    console.log("created mock object");
    return;
  }

  try {
    console.time((0, _utils.formatMsg)("finished fetching shopify products"));
    const shopifyProducts = await (0, _fetch.getShopifyProducts)({
      shopifyClient
    });
    console.timeEnd((0, _utils.formatMsg)("finished fetching shopify products"));
    const productIds = shopifyProducts.edges.map(product => (0, _utils.decodeShopifyId)(product.node.id));
    console.time((0, _utils.formatMsg)("finished fetching yotpo reviews"));
    const reviews = await (0, _fetch.getReviews)({
      productIds,
      yotpoAppKey,
      yotpoPerPage
    });
    console.timeEnd((0, _utils.formatMsg)("finished fetching yotpo reviews"));
    console.time((0, _utils.formatMsg)("finished fetching yotpo questions"));
    const questions = await (0, _fetch.getQuestions)({
      productIds,
      yotpoAppKey,
      yotpoPerPage
    });
    console.timeEnd((0, _utils.formatMsg)("finished fetching yotpo questions"));
    let mergedData = reviews.map(review => {
      const question = questions.find(question => question.productId === review.productId);
      return { ...review,
        ...question
      };
    });
    const mergedProductIds = mergedData.map(data => data.productId);
    const leftoverQuestions = questions.filter(question => !mergedProductIds.includes(question.productId));
    mergedData = mergedData.concat(leftoverQuestions);
    await Promise.all(mergedData.map(async data => {
      const camelCaseData = (0, _camelcaseKeysRecursive.default)(data);
      await (0, _utils.createNodeFactory)(createNode, createNodeId, createContentDigest, camelCaseData);
    }));
  } catch (e) {
    console.error((0, _chalk.default)`\n{red error} an error occurred while sourcing data`);
    throw e;
  }

  return;
};

exports.sourceNodes = sourceNodes;